# LiveKit Plugins Hume AI TTS

LiveKit Agents Framework plugin for [Hume](https://www.hume.ai/) Text-to-Speech API.

## Installation

```bash
pip install livekit-plugins-hume
```

You will need an API Key from Hume, it can be set as an environment variable: `HUME_API_KEY`. You can get it from [here](https://platform.hume.ai/settings/keys)
